<?php
/*
Plugin Name: E-Section
Plugin URI: http://yourdomain.com/
Description: Allows you to manage your posts by section / page
Version: 1.3
Author: Don Kukral
Author URI: http://yourdomain.com
License: GPL
*/
ini_set('display_errors', 0);
ini_set("log_errors", 0);
ini_set("error_log", "/tmp/php-error.log");

define( 'E_SECTION_VERSION' , '1.0' );
define( 'E_SECTION_ROOT' , dirname(__FILE__) );
define( 'E_SECTION_URL' , plugins_url(plugin_basename(dirname(__FILE__)).'/') );
define( 'E_SECTION_PAGE', 'e-section');
define( 'E_SECTION_PAGE_PLANNER_PAGE', 'e-section-page-planner');
define( 'E_SECTION_ADMIN', get_admin_url() . "admin.php?page=" . E_SECTION_PAGE);
define( 'E_SECTION_PAGE_PLANNER_ADMIN', get_admin_url() . "admin.php?page=" . E_SECTION_PAGE_PLANNER_PAGE);

global $e_section_db_ver;
$e_section_db_ver = "1.0";

include_once("php/logger.php");
include_once("php/geo.php");
include_once("php/print-tags.php");
include_once("php/export-posts.php");
include_once("php/page-planner.php");

$esection = new eSection();

add_action( 'admin_menu', array( &$esection, 'menu' ) );
add_action( 'template_redirect', array( &$esection->logger, 'logger' ) );
add_action( 'admin_enqueue_scripts', array( &$esection,'e_section_admin_scripts' ) );
add_action( 'admin_print_styles', array( &$esection, 'e_section_admin_styles' ) );
add_action('admin_menu', array(&$esection->print_tags, 'print_tags_add_custom_box'));
add_action('save_post', array(&$esection->print_tags, 'print_tags_update_tags'));

class eSection {
    
    function __construct() {
        $this->logger = new logger();
        $this->geo = new geo();
        $this->print_tags = new print_tags();
        $this->export_posts = new export_posts();
        $this->page_planner = new page_planner();
        
        $this->pages = array(
            'e-section' => $this, 
            'e-section-logger' => $this->logger,
            'e-section-geo-logger' => $this->geo,
            'e-section-print-tags' => $this->print_tags,
            'e-section-export-posts' => $this->export_posts,
            'e-section-page-planner' => $this->page_planner,
            );
    }
    
    function e_section_admin_scripts() {
        if ((array_key_exists('page', $_GET)) && 
            (in_array($_GET['page'], array_keys($this->pages)))) {
    	    wp_enqueue_script("e-section-js", E_SECTION_URL . "js/e-section.js", array('jquery'), '1.0');	
//    	    wp_enqueue_script('e-section-date-lib', E_SECTION_URL . 'js/date.js', array('jquery'), E_SECTION_VERSION, true);
//			wp_enqueue_script('e-section-date_picker-lib', E_SECTION_URL . 'js/jquery.datePicker.js', array('jquery'), E_SECTION_VERSION, true);
            wp_enqueue_script('e-section-jquery-ui', E_SECTION_URL . 'js/jquery-ui-1.8.18.custom.min.js', array('jquery'), E_SECTION_VERSION, true);
			
    	} else {
    	    wp_deregister_script("e-section-js");
//    	    wp_deregister_script("e-section-date-lib");
//    	    wp_deregister_script("e-section-date_picker-lib");
            wp_deregister_script('e-section-jquery-ui');
    	}

    }
    
    function e_section_admin_styles() {
        if ((array_key_exists('page', $_GET)) && 
            (in_array($_GET['page'], array_keys($this->pages)))) {
            wp_enqueue_style( 'e-section-css', E_SECTION_URL . 'css/e-section.css', false );
            wp_enqueue_style( 'e-section-jquery-ui-css', E_SECTION_URL . 'css/smoothness/jquery-ui-1.8.18.custom.css', false );
        } else {
            wp_deregister_style('e-section-css');
            wp_deregister_style('e-section-jquery-ui-css');
        }
    }
    
    function menu() {  
        return add_menu_page('E-Section', 'E-Section', 'manage_options', 'e-section', array(&$this, "display_page" ) ) &&
            add_submenu_page('e-section', 'Print Tags', 'Print Tags', 'read', 'e-section-print-tags', array(&$this, "display_page")) && 
            add_submenu_page('e-section', 'Export Posts', 'Export Posts', 'read', 'e-section-export-posts', array(&$this, "display_page")) && 
            add_submenu_page('e-section', 'Page Planner', 'Page Planner', 'read', 'e-section-page-planner', array(&$this, "display_page")) && 
            add_submenu_page('e-section', 'Logger', 'Logger', 'read', 'e-section-logger', array(&$this, "display_page")) &&
            add_submenu_page('e-section', 'GEO Logger', 'GEO Logger', 'read', 'e-section-geo-logger', array(&$this, "display_page"));
            
    }
    
    function display_page() {
        $page = $_GET['page'];
        if (in_array($page, array_keys($this->pages))) {
            $this->pages[$page]->view();
        } else {
            $this->soon();
        } 
    }
    
    function view() {
        ?>
        	<div class="wrap" id="e-section-wrap">
        	    <div id="e-section-title">
        	        <h2>E-Section</h2>
        	    </div>
        	</div>    	
        <?php
        echo "default view";
    }

    function soon() {
        ?>
        	<div class="wrap" id="e-section-wrap">
        	    <div id="e-section-title">
        	        <h2>E-Section</h2>
        	    </div>
        	</div>
        <?php
        echo "coming soon";
    }
}


function e_section_install() {
    global $wpdb;
    global $e_section_db_ver;
    
    $table_name = $wpdb->prefix . "e_section";
    
    $sql = "CREATE TABLE " . $table_name . " (
        id MEDIUMINT(9) NOT NULL AUTO_INCREMENT,
        section VARCHAR(25) NOT NULL,
        page VARCHAR(25) NOT NULL,
        city VARCHAR(255) NOT NULL DEFAULT '',
        postal_code VARCHAR(25) NOT NULL DEFAULT '',
        ts TIMESTAMP NOT NULL,
        UNIQUE KEY id (id));";
    
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
    
    add_option("e_section_db_ver", $e_section_db_ver);
    
}

function e_section_update_check() {
    global $e_section_db_ver;
    if (get_site_option('e_section_db_ver') != $e_section_db_ver) {
        e_section_install();
    }
}

register_activation_hook(__FILE__, 'astream_install');
add_action( 'plugins_loaded', 'e_section_update_check');

